@@ -30,7 +30,9 @@ from distutils.command import install as du_install
 import distutils.errors
 from distutils import log
 import pkg_resources
+from setuptools.command import easy_install
 from setuptools.command import install
+from setuptools.command import install_scripts
 from setuptools.command import sdist
 
 try:
@@ -273,14 +275,14 @@ def generate_authors(git_dir=None, dest_dir='.', option_dict=dict()):
                 and not os.access(new_authors, os.W_OK)):
             return
         log.info('[pbr] Generating AUTHORS')
-        jenkins_email = 'jenkins@review'
+        ignore_emails = '(jenkins@review|infra@lists)'
         if git_dir is None:
             git_dir = _get_git_directory()
         if git_dir:
             # don't include jenkins email address in AUTHORS file
             git_log_cmd = ("git --git-dir=" + git_dir +
                            " log --format='%aN <%aE>' | sort -u | "
-                           "egrep -v '" + jenkins_email + "'")
+                           "egrep -v '" + ignore_emails + "'")
             changelog = _run_shell_command(git_log_cmd)
             signed_cmd = ("git log --git-dir=" + git_dir +
                           " | grep -i Co-authored-by: | sort -u")
@@ -430,6 +432,69 @@ def have_nose():
     return _have_nose
 
 
+_script_text = """# PBR Generated from %(group)r
+
+import sys
+
+from %(module_name)s import %(func)s
+
+
+if __name__ == "__main__":
+    sys.exit(%(func)s())
+"""
+
+
+def override_get_script_args(
+        dist, executable=os.path.normpath(sys.executable), is_wininst=False):
+    """Override entrypoints console_script."""
+    header = easy_install.get_script_header("", executable, is_wininst)
+    for group in 'console_scripts', 'gui_scripts':
+        for name, ep in dist.get_entry_map(group).items():
+            script_text = _script_text % dict(
+                group=group,
+                module_name=ep.module_name,
+                func=ep.attrs[0])
+            yield (name, header+script_text)
+
+
+class LocalInstallScripts(install_scripts.install_scripts):
+    """Intercepts console scripts entry_points."""
+    command_name = 'install_scripts'
+
+    def run(self):
+        if os.name != 'nt':
+            get_script_args = override_get_script_args
+        else:
+            get_script_args = easy_install.get_script_args
+
+        import distutils.command.install_scripts
+
+        self.run_command("egg_info")
+        if self.distribution.scripts:
+            # run first to set up self.outfiles
+            distutils.command.install_scripts.install_scripts.run(self)
+        else:
+            self.outfiles = []
+        if self.no_ep:
+            # don't install entry point scripts into .egg file!
+            return
+
+        ei_cmd = self.get_finalized_command("egg_info")
+        dist = pkg_resources.Distribution(
+            ei_cmd.egg_base,
+            pkg_resources.PathMetadata(ei_cmd.egg_base, ei_cmd.egg_info),
+            ei_cmd.egg_name, ei_cmd.egg_version,
+        )
+        bs_cmd = self.get_finalized_command('build_scripts')
+        executable = getattr(
+            bs_cmd, 'executable', easy_install.sys_executable)
+        is_wininst = getattr(
+            self.get_finalized_command("bdist_wininst"), '_is_running', False
+        )
+        for args in get_script_args(dist, executable, is_wininst):
+            self.write_script(*args)
+
+
 class LocalSDist(sdist.sdist):
     """Builds the ChangeLog and Authors files from VC first."""
 
