@@ -4,17 +4,17 @@
 # Copyright (c) 2013 Hewlett-Packard Development Company, L.P.
 # All Rights Reserved.
 #
-#    Licensed under the Apache License, Version 2.0 (the "License"); you may
-#    not use this file except in compliance with the License. You may obtain
-#    a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
 #
-#         http://www.apache.org/licenses/LICENSE-2.0
+#      http://www.apache.org/licenses/LICENSE-2.0
 #
-#    Unless required by applicable law or agreed to in writing, software
-#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-#    License for the specific language governing permissions and limitations
-#    under the License.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 from __future__ import print_function
 
@@ -22,7 +22,13 @@ import os
 import sys
 import tempfile
 
-from d2to1.extern import six
+try:
+    import cStringIO as io
+    BytesIO = io.StringIO
+except ImportError:
+    import io
+    BytesIO = io.BytesIO
+
 import fixtures
 import testscenarios
 
@@ -30,22 +36,6 @@ from pbr import packaging
 from pbr import tests
 
 
-class DiveDir(fixtures.Fixture):
-    """Dive into given directory and return back on cleanup.
-
-    :ivar path: The target directory.
-    """
-
-    def __init__(self, path):
-        self.path = path
-
-    def setUp(self):
-        super(DiveDir, self).setUp()
-        self.old_path = os.getcwd()
-        os.chdir(self.path)
-        self.addCleanup(os.chdir, self.old_path)
-
-
 class EmailTestCase(tests.BaseTestCase):
 
     def test_str_dict_replace(self):
@@ -165,8 +155,8 @@ class GitLogsTest(tests.BaseTestCase):
             "os.path.exists",
             lambda path: os.path.abspath(path) in exist_files))
         self.useFixture(fixtures.FakePopen(lambda _: {
-            "stdout": six.BytesIO("Author: Foo Bar "
-                                  "<email@bar.com>\n".encode('utf-8'))
+            "stdout": BytesIO("Author: Foo Bar "
+                              "<email@bar.com>\n".encode('utf-8'))
         }))
 
         def _fake_read_git_mailmap(*args):
@@ -207,7 +197,7 @@ class GitLogsTest(tests.BaseTestCase):
             lambda path: os.path.abspath(path) in exist_files))
 
         self.useFixture(fixtures.FakePopen(lambda proc_args: {
-            "stdout": six.BytesIO(
+            "stdout": BytesIO(
                 self._fake_log_output(proc_args["args"][2], cmd_map))
         }))
 
@@ -250,7 +240,7 @@ class BuildSphinxTest(tests.BaseTestCase):
         pkg_fixture = fixtures.PythonPackage(
             "fake_package", [("fake_module.py", b"")])
         self.useFixture(pkg_fixture)
-        self.useFixture(DiveDir(pkg_fixture.base))
+        self.useFixture(tests.DiveDir(pkg_fixture.base))
 
     def test_build_doc(self):
         if self.has_opt:
